@@ -8,7 +8,7 @@ structure, dynamics, and functions of complex networks.
 See https://networkx.org for complete documentation.
 """
 
-__version__ = "2.8.4"
+__version__ = "2.8.5"
 
 
 def __getattr__(name):
@@ -52,7 +52,7 @@ def __getattr__(name):
 
 
 # These are imported in order as listed
-from networkx.lazy_imports import lazy_import
+from networkx.lazy_imports import _lazy_import
 
 from networkx.exception import *
 
