@@ -1,11 +1,13 @@
 from collections import UserDict
 
 import pytest
-from networkx.utils import edges_equal
+
 import networkx as nx
+from networkx.utils import edges_equal
+
 from .test_multigraph import BaseMultiGraphTester
-from .test_multigraph import TestMultiGraph as _TestMultiGraph
 from .test_multigraph import TestEdgeSubgraph as _TestMultiGraphEdgeSubgraph
+from .test_multigraph import TestMultiGraph as _TestMultiGraph
 
 
 class BaseMultiDiGraphTester(BaseMultiGraphTester):
@@ -257,8 +259,8 @@ class TestMultiDiGraph(BaseMultiDiGraphTester, _TestMultiGraph):
         self.k3edges = [(0, 1), (0, 2), (1, 2)]
         self.k3nodes = [0, 1, 2]
         self.K3 = self.Graph()
-        self.K3._adj = {0: {}, 1: {}, 2: {}}
-        self.K3._succ = self.K3._adj
+        self.K3._succ = {0: {}, 1: {}, 2: {}}
+        # K3._adj is synced with K3._succ
         self.K3._pred = {0: {}, 1: {}, 2: {}}
         for u in self.k3nodes:
             for v in self.k3nodes:
@@ -414,7 +416,7 @@ class CustomDictClass(UserDict):
     pass
 
 
-class SubMultiDiGraph(nx.MultiDiGraph):
+class MultiDiGraphSubClass(nx.MultiDiGraph):
     node_dict_factory = CustomDictClass  # type: ignore
     node_attr_dict_factory = CustomDictClass  # type: ignore
     adjlist_outer_dict_factory = CustomDictClass  # type: ignore
@@ -426,19 +428,19 @@ class SubMultiDiGraph(nx.MultiDiGraph):
 
 class TestMultiDiGraphSubclass(TestMultiDiGraph):
     def setup_method(self):
-        self.Graph = SubMultiDiGraph
+        self.Graph = MultiDiGraphSubClass
         # build K3
         self.k3edges = [(0, 1), (0, 2), (1, 2)]
         self.k3nodes = [0, 1, 2]
         self.K3 = self.Graph()
-        self.K3._adj = self.K3.adjlist_outer_dict_factory(
+        self.K3._succ = self.K3.adjlist_outer_dict_factory(
             {
                 0: self.K3.adjlist_inner_dict_factory(),
                 1: self.K3.adjlist_inner_dict_factory(),
                 2: self.K3.adjlist_inner_dict_factory(),
             }
         )
-        self.K3._succ = self.K3._adj
+        # K3._adj is synced with K3._succ
         self.K3._pred = {0: {}, 1: {}, 2: {}}
         for u in self.k3nodes:
             for v in self.k3nodes:
