@@ -236,6 +236,13 @@ def set_warnings():
     )
     warnings.filterwarnings("ignore", category=DeprecationWarning, message="info")
     warnings.filterwarnings("ignore", category=DeprecationWarning, message="to_tuple")
+    # create_using for scale_free_graph
+    warnings.filterwarnings(
+        "ignore", category=DeprecationWarning, message="The create_using argument"
+    )
+    warnings.filterwarnings(
+        "ignore", category=PendingDeprecationWarning, message="nx.nx_pydot"
+    )
 
 
 @pytest.fixture(autouse=True)
