@@ -17,15 +17,16 @@ See Also
  - :obj:`matplotlib.patches.FancyArrowPatch`
 """
 from numbers import Number
+
 import networkx as nx
 from networkx.drawing.layout import (
-    shell_layout,
     circular_layout,
     kamada_kawai_layout,
+    planar_layout,
+    random_layout,
+    shell_layout,
     spectral_layout,
     spring_layout,
-    random_layout,
-    planar_layout,
 )
 
 __all__ = [
@@ -268,58 +269,25 @@ def draw_networkx(G, pos=None, arrows=None, with_labels=True, **kwds):
     draw_networkx_labels
     draw_networkx_edge_labels
     """
+    from inspect import signature
+
     import matplotlib.pyplot as plt
 
-    valid_node_kwds = (
-        "nodelist",
-        "node_size",
-        "node_color",
-        "node_shape",
-        "alpha",
-        "cmap",
-        "vmin",
-        "vmax",
-        "ax",
-        "linewidths",
-        "edgecolors",
-        "label",
-    )
+    # Get all valid keywords by inspecting the signatures of draw_networkx_nodes,
+    # draw_networkx_edges, draw_networkx_labels
 
-    valid_edge_kwds = (
-        "edgelist",
-        "width",
-        "edge_color",
-        "style",
-        "alpha",
-        "arrowstyle",
-        "arrowsize",
-        "edge_cmap",
-        "edge_vmin",
-        "edge_vmax",
-        "ax",
-        "label",
-        "node_size",
-        "nodelist",
-        "node_shape",
-        "connectionstyle",
-        "min_source_margin",
-        "min_target_margin",
-    )
+    valid_node_kwds = signature(draw_networkx_nodes).parameters.keys()
+    valid_edge_kwds = signature(draw_networkx_edges).parameters.keys()
+    valid_label_kwds = signature(draw_networkx_labels).parameters.keys()
 
-    valid_label_kwds = (
-        "labels",
-        "font_size",
-        "font_color",
-        "font_family",
-        "font_weight",
-        "alpha",
-        "bbox",
-        "ax",
-        "horizontalalignment",
-        "verticalalignment",
-    )
-
-    valid_kwds = valid_node_kwds + valid_edge_kwds + valid_label_kwds
+    # Create a set with all valid keywords across the three functions and
+    # remove the arguments of this function (draw_networkx)
+    valid_kwds = (valid_node_kwds | valid_edge_kwds | valid_label_kwds) - {
+        "G",
+        "pos",
+        "arrows",
+        "with_labels",
+    }
 
     if any([k not in valid_kwds for k in kwds]):
         invalid_args = ", ".join([k for k in kwds if k not in valid_kwds])
@@ -438,10 +406,11 @@ def draw_networkx_nodes(
     draw_networkx_edge_labels
     """
     from collections.abc import Iterable
-    import numpy as np
+
     import matplotlib as mpl
     import matplotlib.collections  # call as mpl.collections
     import matplotlib.pyplot as plt
+    import numpy as np
 
     if ax is None:
         ax = plt.gca()
@@ -669,13 +638,13 @@ def draw_networkx_edges(
     draw_networkx_edge_labels
 
     """
-    import numpy as np
     import matplotlib as mpl
+    import matplotlib.collections  # call as mpl.collections
     import matplotlib.colors  # call as mpl.colors
     import matplotlib.patches  # call as mpl.patches
-    import matplotlib.collections  # call as mpl.collections
     import matplotlib.path  # call as mpl.path
     import matplotlib.pyplot as plt
+    import numpy as np
 
     # The default behavior is to use LineCollection to draw edges for
     # undirected graphs (for performance reasons) and use FancyArrowPatches
@@ -1508,11 +1477,12 @@ def apply_alpha(colors, alpha, elem_list, cmap=None, vmin=None, vmax=None):
         Array containing RGBA format values for each of the node colours.
 
     """
-    from itertools import islice, cycle
-    import numpy as np
+    from itertools import cycle, islice
+
     import matplotlib as mpl
-    import matplotlib.colors  # call as mpl.colors
     import matplotlib.cm  # call as mpl.cm
+    import matplotlib.colors  # call as mpl.colors
+    import numpy as np
 
     # If we have been provided with a list of numbers as long as elem_list,
     # apply the color mapping.
